@@ -10,11 +10,13 @@ class Figure:
         self._label = label
         # important to define the figure here - because it does the check to see if the data is too large
         self._figure = fig.Figure(
-            view_url=os.getenv('SPIKESORTINGVIEW_URL', 'gs://figurl/spikesortingview-4'),
+            view_url=os.getenv('SPIKESORTINGVIEW_URL', 'gs://figurl/spikesortingview-8'),
             data=self._data
         )
     def url(self):
         return self._figure.url(label=self._label, project_id=kcl.get_project_id())
+    def electron(self):
+        return self._figure.electron(label=self._label)
     def get_serialized_figure_data(self):
         return self._figure._serialized_data
     @property
