@@ -2,7 +2,15 @@ from typing import Union
 import kachery_cloud as kcl
 from ..SpikeSortingView import SpikeSortingView
 
-def spikesortingview(self, *, recording_id: str, sorting_id: str, label: str):
+def spikesortingview(self, *,
+    recording_id: str,
+    sorting_id: str,
+    label: str,
+    _raster_plot_subsample_max_firing_rate: Union[None, float]=None,
+    _spike_amplitudes_subsample_max_firing_rate: Union[None, float]=None,
+):
+    from .Workspace import Workspace
+    self: Workspace = self
     R = self.get_recording_extractor(recording_id)
     S = self.get_sorting_extractor(sorting_id)
 
@@ -24,9 +32,9 @@ def spikesortingview(self, *, recording_id: str, sorting_id: str, label: str):
     f1 = X.create_summary()
     f2 = X.create_units_table(unit_ids=X.unit_ids, unit_metrics=unit_metrics)
     f3 = X.create_autocorrelograms(unit_ids=X.unit_ids)
-    f4 = X.create_raster_plot(unit_ids=X.unit_ids)
+    f4 = X.create_raster_plot(unit_ids=X.unit_ids, _subsample_max_firing_rate=_raster_plot_subsample_max_firing_rate)
     f5 = X.create_average_waveforms(unit_ids=X.unit_ids)
-    f6 = X.create_spike_amplitudes(unit_ids=X.unit_ids)
+    f6 = X.create_spike_amplitudes(unit_ids=X.unit_ids, _subsample_max_firing_rate=_spike_amplitudes_subsample_max_firing_rate)
     f7 = X.create_electrode_geometry()
     f8 = X.create_live_cross_correlograms()
 
@@ -37,4 +45,4 @@ def spikesortingview(self, *, recording_id: str, sorting_id: str, label: str):
     )
 
     url = mountain_layout.url()
-    return url
\ No newline at end of file
+    return url
